local E, L, V, P, G, _ = unpack(ElvUI);

local DataText = E:GetModule("DataTexts")
local Misc = E["Miscellaneous"]
local y = E.db["chat"]["panelHeight"] + E.db["chat"]["panelHeight"]

local menuFrame = CreateFrame("Frame", "MaUIMenu", E.UIParent, "UIDropDownMenuTemplate")

local menuList = {
	{text = CHARACTER_BUTTON, notCheckable = true, func = function() ToggleCharacter("PaperDollFrame") end},
	{text = SPELLBOOK_ABILITIES_BUTTON, notCheckable = true, func = function() if not SpellBookFrame:IsShown() then ShowUIPanel(SpellBookFrame) else HideUIPanel(SpellBookFrame) end end},
	{text = TALENTS_BUTTON, notCheckable = true, 
	func = function()
		if not PlayerTalentFrame then
			TalentFrame_LoadUI()
		end

		if not PlayerTalentFrame:IsShown() then
			ShowUIPanel(PlayerTalentFrame)
		else
			HideUIPanel(PlayerTalentFrame)
		end
	end},
	{text = LFG_TITLE, notCheckable = true, func = function() ToggleLFDParentFrame(); end},
	{text = ACHIEVEMENT_BUTTON, notCheckable = true, func = function() ToggleAchievementFrame() end},
	{text = REPUTATION, notCheckable = true, func = function() ToggleCharacter('ReputationFrame') end},
	{text = GARRISON_LANDING_PAGE_TITLE, notCheckable = true, func = function() GarrisonLandingPageMinimapButton_OnClick() end},
	{text = ACHIEVEMENTS_GUILD_TAB, notCheckable = true, 
	func = function()
		if IsInGuild() then
			if not GuildFrame then GuildFrame_LoadUI() end
			GuildFrame_Toggle()
		else
			if not LookingForGuildFrame then LookingForGuildFrame_LoadUI() end
			if not LookingForGuildFrame then return end
			LookingForGuildFrame_Toggle()
		end
	end},
	{text = L["Calendar"], notCheckable = true, func = function() GameTimeFrame:Click() end},
	{text = MOUNTS, notCheckable = true, func = function() ToggleCollectionsJournal(1) end},
	{text = PET_JOURNAL, notCheckable = true, func = function() ToggleCollectionsJournal(2) end},
	{text = TOY_BOX, notCheckable = true, func = function() ToggleCollectionsJournal(3) end},
	{text = HEIRLOOMS, notCheckable = true, func = function() ToggleCollectionsJournal(4) end},
	{text = WARDROBE, notCheckable = true, func = function() ToggleCollectionsJournal(5) end},
	{text = MACROS, notCheckable = true, func = function() GameMenuButtonMacros:Click() end},
	{text = TIMEMANAGER_TITLE, notCheckable = true, func = function() ToggleFrame(TimeManagerFrame) end},
	{text = ENCOUNTER_JOURNAL, notCheckable = true, func = function() if not IsAddOnLoaded('Blizzard_EncounterJournal') then EncounterJournal_LoadUI(); end ToggleFrame(EncounterJournal) end},
	{text = SOCIAL_BUTTON, notCheckable = true, func = function() ToggleFriendsFrame() end},
	{text = MAINMENU_BUTTON, notCheckable = true, 
	func = function()
		if ( not GameMenuFrame:IsShown() ) then
			if ( VideoOptionsFrame:IsShown() ) then
					VideoOptionsFrameCancel:Click();
			elseif ( AudioOptionsFrame:IsShown() ) then
					AudioOptionsFrameCancel:Click();
			elseif ( InterfaceOptionsFrame:IsShown() ) then
					InterfaceOptionsFrameCancel:Click();
			end
			CloseMenus();
			CloseAllWindows()
			PlaySound("igMainMenuOpen");
			ShowUIPanel(GameMenuFrame);
		else
			PlaySound("igMainMenuQuit");
			HideUIPanel(GameMenuFrame);
			MainMenuMicroButton_SetNormal();
		end
	end},
	{text = HELP_BUTTON, notCheckable = true, func = function() ToggleHelpFrame() end},
	{text = BLIZZARD_STORE, notCheckable = true, func = function() StoreMicroButton:Click() end}
}

local function OnClick(self)
	GameTooltip:Hide()
	EasyMenu(menuList, menuFrame, "cursor", x, y, "MENU", 2)
	PlaySound("igMainMenuOptionCheckBoxOff");
end
	
local function OnEnter(self)
	GameTooltip:SetOwner(self, 'ANCHOR_TOPRIGHT', 0, 2 )
	GameTooltip:ClearLines()
	GameTooltip:AddLine(MAINMENU_BUTTON, selectioncolor)
	GameTooltip:Show()
end

local function OnEvent(self, event, unit)
	self.text:SetText("Menu")
end

local function OnLeave(self)
	GameTooltip:Hide()
end

--[[
	DT:RegisterDatatext(name, events, eventFunc, updateFunc, clickFunc, onEnterFunc, onLeaveFunc)

	name - name of the datatext (required)
	events - must be a table with string values of event names to register
	eventFunc - function that gets fired when an event gets triggered
	updateFunc - onUpdate script target function
	click - function to fire when clicking the datatext
	onEnterFunc - function to fire OnEnter
	onLeaveFunc - function to fire OnLeave, if not provided one will be set for you that hides the tooltip.]]

DataText:RegisterDatatext('Menu', nil, OnEvent, nil, OnClick, OnEnter, OnLeave)